==> nuxt-theme-2.3.0-rc.3.tgz: package/theme/lang/de.js <==
/* eslint-disable  */

export default {
  'Categories': 'Kategorien',
  'Filters': 'Filters',
  'Sort by': 'Sortieren nach',
  'Products found': 'Produkte gefunden',
  'About us': 'Über uns',
  'Who we are': 'Wer wir sind',
  'Quality in the details': 'Qualität im Detail',
  'Customer Reviews': 'Kundenbewertungen',
  'Departments': 'Abteilungen',
  'Women fashion': 'Damenmode',
  'Men fashion': 'Herrenmode',
  'Kidswear': 'Kinderkleidung',
  'Home': 'Zuhause',
  'Help': 'Hilfe',
  'Customer service': 'Kundendienst',
  'Size guide': 'Größentabelle',
  'Contact us': 'Kontaktiere uns',
  'Payment & Delivery': 'Zahlung & Lieferung',
  'Purchase terms': 'Kaufbedingungen',
  'Guarantee': 'Garantie',
  'Description': 'Beschreibung',
  'Read reviews': 'Bewertungen lesen',
  'Additional Information': 'Zusätzliche Information',
  'Save for later': 'Für später speichern',
  'Add to compare': 'Hinzufügen zum vergleichen',
  'Match it with': 'Kombiniere es mit',
  'Share your look': 'Teile deinen Look',
  'Product description': 'Das Karissa V-Neck Tee hat eine halb taillierte Form schmeichelhaft für jede Figur. Sie können mit ins Fitnessstudio gehen Vertrauen, während es Kurven umarmt und häufiges "Problem" verbirgt Bereiche. Finden Sie atemberaubende Cocktailkleider für Frauen und feiern Sie Kleider.',
  'Brand': 'Marke',
  'Instruction1': 'Um mich kümmern',
  'Instruction2': 'Nur hier für die Pflegehinweise?',
  'Instruction3': 'Ja, das haben wir uns gedacht',
  'Items': 'Gegenstände',
  'View': 'Ansicht',
  'Show on page': 'Auf Seite anzeigen',
  'Done': 'Fertig',
  'Clear all': 'Alles löschen',
  'Empty': 'Sieht so aus, als hätten Sie der Tasche noch keine Artikel hinzugefügt. Beginnen Sie mit dem Einkaufen, um es auszufüllen.',
  'Help & FAQs': 'Hilfe & FAQs',
  'Download': 'Laden Sie unsere Anwendung herunter',
  'Find out more': 'Finde mehr heraus',
  'Login': 'Anmeldung',
  'Forgotten password?': 'Passwort vergessen?',
  'No account': `Sie haben noch keinen Account?`,
  'Register today': 'Melde dich noch heute an',
  'Go to checkout': 'Zur Kasse gehen',
  'Go back shopping': 'Zurück einkaufen',
  'Personal details': 'Persönliche Daten',
  'Edit': 'Bearbeiten',
  'Shipping details': 'Versanddetails',
  'Billing address': 'Rechnungsadresse',
  'Same as shipping address': 'Wie Versandadresse',
  'Payment method': 'Zahlungsmethode',
  'Apply': 'Übernehmen',
  'Update password': 'Passwort aktualisieren',
  'Update personal data': 'Persönliche Daten aktualisieren',
  'Item': 'Artikel',
  'Go back': 'Go back',
  'Continue to shipping': 'Weiter zum Versand',
  'I agree to': 'Ich stimme zu',
  'Terms and conditions': 'Allgemeine Geschäftsbedingungen',
  'Pay for order': 'Für Bestellung bezahlen',
  'Log into your account': 'In dein Konto einloggen',
  'or fill the details below': 'oder füllen Sie die Details unten',
  'Enjoy your free account': 'Enjoy these perks with your free account!',
  'Continue to payment': 'Weiter zur Zahlung',
  'Order No.': 'Bestellnummer',
  'Successful placed order': 'Sie haben die Bestellung erfolgreich aufgegeben. Sie können den Status Ihres Bestellen Sie über unsere Lieferstatusfunktion. Sie erhalten eine Bestellung Bestätigungs-E-Mail mit Details Ihrer Bestellung und einem Link zum Verfolgen der Bestellung Fortschritt.',
  'Info after order': 'Sie können sich mit E-Mail und definiertem Passwort in Ihrem Konto anmelden vorhin. Überprüfen Sie in Ihrem Konto Ihre Profildaten Transaktionsverlauf, Abonnement für Newsletter bearbeiten.',
  'Allow order notifications': 'Bestellbenachrichtigungen zulassen',
  'Feedback': 'Ihr Feedback ist uns wichtig. Lassen Sie uns wissen, was wir verbessern können.',
  'Send my feedback': 'Senden Sie mein Feedback',
  'Go back to shop': 'Zurück zum Einkaufen',
  'Read all reviews': 'Alle Bewertungen lesen',
  'Color': 'Farbe',
  'Contact details updated': 'Halten Sie Ihre Adressen und Kontaktdaten auf dem neuesten Stand.',
  'Manage billing addresses': 'Alle gewünschten Rechnungsadressen verwalten (Arbeitsplatz, Privatadresse ...) Auf diese Weise müssen Sie die Rechnungsadresse nicht bei jeder Bestellung manuell eingeben.',
  'Change': 'Änderungsänderung',
  'Delete': 'Löschen',
  'Add new address': 'Neue Adresse hinzufügen',
  'Set up newsletter': 'Richten Sie Ihren Newsletter ein und wir senden Ihnen wöchentlich Informationen zu neuen Produkten und Trends aus den von Ihnen ausgewählten Bereichen',
  'Sections that interest you': 'Abschnitte, die Sie interessieren',
  'Save changes': 'Änderungen speichern',
  'Read and understand': 'Ich habe das gelesen und verstanden',
  'Privacy': 'Datenschutz',
  'Cookies Policy': 'Cookie-Richtlinie',
  'Commercial information': 'und erklären sich damit einverstanden, personalisierte Handelsinformationen vom Markennamen per E-Mail zu erhalten',
  'Feel free to edit': 'Fühlen Sie sich frei, Ihre unten stehenden Daten zu bearbeiten, damit Ihr Konto immer auf dem neuesten Stand ist',
  'Use your personal data': 'Bei Markennamen legen wir großen Wert auf Datenschutzfragen und verpflichten uns, die persönlichen Daten unserer Benutzer zu schützen. Erfahren Sie mehr darüber, wie wir Ihre persönlichen Daten pflegen und verwenden',
  'Privacy Policy': 'Datenschutzrichtlinie',
  'Change password your account': 'Wenn Sie das Passwort ändern möchten, um auf Ihr Konto zuzugreifen, geben Sie die folgenden Informationen ein',
  'Your current email address is': 'Ihre aktuelle E-Mail-Adresse lautet',
  'Product': 'Produkt',
  'Details and status orders': 'Überprüfen Sie die Details und den Status Ihrer Bestellungen im Online-Shop. Sie können Ihre Bestellung auch stornieren oder eine Rücksendung anfordern. ',
  'You currently have no orders': 'Sie haben derzeit keine Bestellungen',
  'Start shopping': 'Einkaufen starten',
  'Download': 'Herunterladen',
  'Download all': 'Alle herunterladen',
  'View details': 'Details anzeigen',
  'Manage shipping addresses': 'Alle gewünschten Versandadressen verwalten (Arbeitsplatz, Privatadresse ...) Auf diese Weise müssen Sie die Versandadresse nicht bei jeder Bestellung manuell eingeben.',
  'Quantity': 'Menge',
  'Price': 'Preis',
  'Back to homepage': 'Zurück zur Homepage',
  'Select shipping method': 'Versandart auswählen',
  'Review my order': 'Meine Bestellung überprüfen',
  'Select payment method': 'Zahlungsmethode auswählen',
  'Make an order': 'Bestellung aufgeben',
  'or': 'oder',
  'login in to your account': 'Anmelden bei Ihrem Konto',
  'Create an account': 'Konto erstellen',
  'Your bag is empty': 'Ihre Tasche ist leer',
  'Cancel': 'Abbrechen',
  'See all results': 'Alle Ergebnisse anzeigen',
  'You haven’t searched for items yet': 'Sie haben noch nicht nach Artikeln gesucht.',
  'Let’s start now – we’ll help you': 'Fangen wir jetzt an - wir helfen Ihnen.',
  'Search results': 'Suchergebnisse',
  'Product suggestions': 'Produktvorschläge',
  'Search for items': 'Nach Artikeln suchen'
};

==> nuxt-theme-2.4.0.tgz: package/theme/lang/de.js <==
/* eslint-disable  */

export default {
  'Categories': 'Kategorien',
  'Filters': 'Filters',
  'Sort by': 'Sortieren nach',
  'Products found': 'Produkte gefunden',
  'About us': 'Über uns',
  'Who we are': 'Wer wir sind',
  'Quality in the details': 'Qualität im Detail',
  'Customer Reviews': 'Kundenbewertungen',
  'Departments': 'Abteilungen',
  'Women fashion': 'Damenmode',
  'Men fashion': 'Herrenmode',
  'Kidswear': 'Kinderkleidung',
  'Home': 'Zuhause',
  'Help': 'Hilfe',
  'Customer service': 'Kundendienst',
  'Size guide': 'Größentabelle',
  'Contact us': 'Kontaktiere uns',
  'Payment & Delivery': 'Zahlung & Lieferung',
  'Purchase terms': 'Kaufbedingungen',
  'Guarantee': 'Garantie',
  'Description': 'Beschreibung',
  'Read reviews': 'Bewertungen lesen',
  'Additional Information': 'Zusätzliche Information',
  'Save for later': 'Für später speichern',
  'Add to compare': 'Hinzufügen zum vergleichen',
  'Match it with': 'Kombiniere es mit',
  'Share your look': 'Teile deinen Look',
  'Product description': 'Das Karissa V-Neck Tee hat eine halb taillierte Form schmeichelhaft für jede Figur. Sie können mit ins Fitnessstudio gehen Vertrauen, während es Kurven umarmt und häufiges "Problem" verbirgt Bereiche. Finden Sie atemberaubende Cocktailkleider für Frauen und feiern Sie Kleider.',
  'Brand': 'Marke',
  'Instruction1': 'Um mich kümmern',
  'Instruction2': 'Nur hier für die Pflegehinweise?',
  'Instruction3': 'Ja, das haben wir uns gedacht',
  'Items': 'Gegenstände',
  'View': 'Ansicht',
  'Show on page': 'Auf Seite anzeigen',
  'Done': 'Fertig',
  'Clear all': 'Alles löschen',
  'Empty': 'Sieht so aus, als hätten Sie der Tasche noch keine Artikel hinzugefügt. Beginnen Sie mit dem Einkaufen, um es auszufüllen.',
  'Help & FAQs': 'Hilfe & FAQs',
  'Download': 'Laden Sie unsere Anwendung herunter',
  'Find out more': 'Finde mehr heraus',
  'Login': 'Anmeldung',
  'Forgotten password?': 'Passwort vergessen?',
  'No account': `Sie haben noch keinen Account?`,
  'Register today': 'Melde dich noch heute an',
  'Go to checkout': 'Zur Kasse gehen',
  'Go back shopping': 'Zurück einkaufen',
  'Personal details': 'Persönliche Daten',
  'Edit': 'Bearbeiten',
  'Shipping details': 'Versanddetails',
  'Billing address': 'Rechnungsadresse',
  'Same as shipping address': 'Wie Versandadresse',
  'Payment method': 'Zahlungsmethode',
  'Apply': 'Übernehmen',
  'Update password': 'Passwort aktualisieren',
  'Update personal data': 'Persönliche Daten aktualisieren',
  'Item': 'Artikel',
  'Go back': 'Go back',
  'Continue to shipping': 'Weiter zum Versand',
  'I agree to': 'Ich stimme zu',
  'Terms and conditions': 'Allgemeine Geschäftsbedingungen',
  'Pay for order': 'Für Bestellung bezahlen',
  'Log into your account': 'In dein Konto einloggen',
  'or fill the details below': 'oder füllen Sie die Details unten',
  'Enjoy your free account': 'Enjoy these perks with your free account!',
  'Continue to payment': 'Weiter zur Zahlung',
  'Order No.': 'Bestellnummer',
  'Successful placed order': 'Sie haben die Bestellung erfolgreich aufgegeben. Sie können den Status Ihres Bestellen Sie über unsere Lieferstatusfunktion. Sie erhalten eine Bestellung Bestätigungs-E-Mail mit Details Ihrer Bestellung und einem Link zum Verfolgen der Bestellung Fortschritt.',
  'Info after order': 'Sie können sich mit E-Mail und definiertem Passwort in Ihrem Konto anmelden vorhin. Überprüfen Sie in Ihrem Konto Ihre Profildaten Transaktionsverlauf, Abonnement für Newsletter bearbeiten.',
  'Allow order notifications': 'Bestellbenachrichtigungen zulassen',
  'Feedback': 'Ihr Feedback ist uns wichtig. Lassen Sie uns wissen, was wir verbessern können.',
  'Send my feedback': 'Senden Sie mein Feedback',
  'Go back to shop': 'Zurück zum Einkaufen',
  'Read all reviews': 'Alle Bewertungen lesen',
  'Color': 'Farbe',
  'Contact details updated': 'Halten Sie Ihre Adressen und Kontaktdaten auf dem neuesten Stand.',
  'Manage billing addresses': 'Alle gewünschten Rechnungsadressen verwalten (Arbeitsplatz, Privatadresse ...) Auf diese Weise müssen Sie die Rechnungsadresse nicht bei jeder Bestellung manuell eingeben.',
  'Change': 'Änderungsänderung',
  'Delete': 'Löschen',
  'Add new address': 'Neue Adresse hinzufügen',
  'Set up newsletter': 'Richten Sie Ihren Newsletter ein und wir senden Ihnen wöchentlich Informationen zu neuen Produkten und Trends aus den von Ihnen ausgewählten Bereichen',
  'Sections that interest you': 'Abschnitte, die Sie interessieren',
  'Save changes': 'Änderungen speichern',
  'Read and understand': 'Ich habe das gelesen und verstanden',
  'Privacy': 'Datenschutz',
  'Cookies Policy': 'Cookie-Richtlinie',
  'Commercial information': 'und erklären sich damit einverstanden, personalisierte Handelsinformationen vom Markennamen per E-Mail zu erhalten',
  'Feel free to edit': 'Fühlen Sie sich frei, Ihre unten stehenden Daten zu bearbeiten, damit Ihr Konto immer auf dem neuesten Stand ist',
  'Use your personal data': 'Bei Markennamen legen wir großen Wert auf Datenschutzfragen und verpflichten uns, die persönlichen Daten unserer Benutzer zu schützen. Erfahren Sie mehr darüber, wie wir Ihre persönlichen Daten pflegen und verwenden',
  'Privacy Policy': 'Datenschutzrichtlinie',
  'Change password your account': 'Wenn Sie das Passwort ändern möchten, um auf Ihr Konto zuzugreifen, geben Sie die folgenden Informationen ein',
  'Your current email address is': 'Ihre aktuelle E-Mail-Adresse lautet',
  'Product': 'Produkt',
  'Details and status orders': 'Überprüfen Sie die Details und den Status Ihrer Bestellungen im Online-Shop. Sie können Ihre Bestellung auch stornieren oder eine Rücksendung anfordern. ',
  'You currently have no orders': 'Sie haben derzeit keine Bestellungen',
  'Start shopping': 'Einkaufen starten',
  'Download': 'Herunterladen',
  'Download all': 'Alle herunterladen',
  'View details': 'Details anzeigen',
  'Manage shipping addresses': 'Alle gewünschten Versandadressen verwalten (Arbeitsplatz, Privatadresse ...) Auf diese Weise müssen Sie die Versandadresse nicht bei jeder Bestellung manuell eingeben.',
  'Quantity': 'Menge',
  'Price': 'Preis',
  'Back to homepage': 'Zurück zur Homepage',
  'Select shipping method': 'Versandart auswählen',
  'Review my order': 'Meine Bestellung überprüfen',
  'Select payment method': 'Zahlungsmethode auswählen',
  'Make an order': 'Bestellung aufgeben',
  'or': 'oder',
  'login in to your account': 'Anmelden bei Ihrem Konto',
  'Create an account': 'Konto erstellen',
  'Your bag is empty': 'Ihre Tasche ist leer',
  'Cancel': 'Abbrechen',
  'See all results': 'Alle Ergebnisse anzeigen',
  'You haven’t searched for items yet': 'Sie haben noch nicht nach Artikeln gesucht.',
  'Let’s start now – we’ll help you': 'Fangen wir jetzt an - wir helfen Ihnen.',
  'Search results': 'Suchergebnisse',
  'Product suggestions': 'Produktvorschläge',
  'Search for items': 'Nach Artikeln suchen',
  'Enter promo code': 'Geben Sie den Promo-Code ein',
  'Shipping method': 'Versandart',
  'Continue to billing': 'Weiter zur Abrechnung',
  'Payment methods': 'Zahlungsmethoden',
  'Shipping address': 'Lieferanschrift',
  'Subtotal': 'Zwischensumme',
  'Shipping': 'Versand',
  'Total price': 'Gesamtpreis',
  'Payment': 'Zahlung',
  'Order summary': 'Bestellübersicht',
  'Products': 'Produkte',
  'Total': 'Gesamt',
  'Reset Password': 'Passwort Zurücksetzen',
  'Save Password': 'Passwort Speichern',
  'Back to home': 'Zurück Zur Startseite',
  'Forgot Password': 'Wenn Sie Ihr Passwort vergessen haben, können Sie es zurücksetzen.',
  'Thank You Inbox': 'Wenn die Nachricht nicht in Ihrem Posteingang ankommt, versuchen Sie es mit einer anderen E-Mail-Adresse, mit der Sie sich möglicherweise registriert haben.',
  'Sign in': 'Einloggen',
  'Register': 'Registrieren',
  'Password Changed': 'Passwort erfolgreich geändert. Sie können nun zur Startseite zurückkehren und sich anmelden.',
  'Password': 'Passwort',
  'Repeat Password': 'Wiederhole das Passwort',
  'Forgot Password Modal Email': 'E-Mail, mit der Sie sich anmelden:',
  forgotPasswordConfirmation: 'Vielen Dank! Wenn ein Konto mit der E-Mail-Adresse {0} registriert ist, finden Sie in Ihrem Posteingang eine Nachricht mit einem Link zum Zurücksetzen des Passworts.'
};
